==> pf4-component-mapper-3.20.0.tgz: package/esm/select/select/option.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["item", "isActive", "isSelected"];
import React from 'react';
import PropTypes from 'prop-types';
import CheckIcon from "@patternfly/react-icons/dist/esm/icons/check-icon";

var Option = function Option(_ref) {
  var item = _ref.item,
      isActive = _ref.isActive,
      isSelected = _ref.isSelected,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("button", _extends({}, props, {
    disabled: item.isDisabled || item.disabled,
    type: "button",
    className: "pf-c-select__menu-item".concat(isSelected ? ' pf-m-selected' : '').concat(isActive ? ' pf-m-focus' : '').concat(item.isDisabled || item.disabled ? ' pf-m-disabled' : '')
  }), item.label, isSelected && /*#__PURE__*/React.createElement("span", {
    className: "pf-c-select__menu-item-icon"
  }, /*#__PURE__*/React.createElement(CheckIcon, null)), item.description && /*#__PURE__*/React.createElement("div", {
    className: "pf-c-select__menu-item-description"
  }, item.description)));
};

Option.propTypes = {
  item: PropTypes.shape({
    label: PropTypes.node,
    isDisabled: PropTypes.bool,
    disabled: PropTypes.bool,
    description: PropTypes.node
  }).isRequired,
  isActive: PropTypes.bool,
  isSelected: PropTypes.bool,
  onClick: PropTypes.func.isRequired
};
export default Option;

==> pf4-component-mapper-3.23.0.tgz: package/esm/select/select/option.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["item", "isActive", "isSelected"];
import React from 'react';
import PropTypes from 'prop-types';
import CheckIcon from "@patternfly/react-icons/dist/dynamic/icons/check-icon";

var Option = function Option(_ref) {
  var item = _ref.item,
      isActive = _ref.isActive,
      isSelected = _ref.isSelected,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("button", _extends({}, props, {
    disabled: item.isDisabled || item.disabled,
    type: "button",
    className: "pf-v5-c-select__menu-item".concat(isSelected ? ' pf-m-selected' : '').concat(isActive ? ' pf-m-focus' : '').concat(item.isDisabled || item.disabled ? ' pf-m-disabled' : '')
  }), item.label, isSelected && /*#__PURE__*/React.createElement("span", {
    className: "pf-v5-c-select__menu-item-icon"
  }, /*#__PURE__*/React.createElement(CheckIcon, null)), item.description && /*#__PURE__*/React.createElement("div", {
    className: "pf-v5-c-select__menu-item-description"
  }, item.description)));
};

Option.propTypes = {
  item: PropTypes.shape({
    label: PropTypes.node,
    isDisabled: PropTypes.bool,
    disabled: PropTypes.bool,
    description: PropTypes.node
  }).isRequired,
  isActive: PropTypes.bool,
  isSelected: PropTypes.bool,
  onClick: PropTypes.func.isRequired
};
export default Option;
